import PropTypes from 'prop-types';
import React from "react";
import 'chart.js/auto';
import { Bar } from 'react-chartjs-2';
import _ from 'lodash';
import { DataTable } from 'primereact/datatable';
import { Column } from 'primereact/column';
/**
 * Component to show data ingested per site in cycle(s).
 */

export default function CycleSiteWiseData(props) {

    let { data } = props;

    const getBarData = () => {
        return {
            labels: _.map(data, 'cycle'),
            datasets: [

                {
                    label: 'Poznan',
                    data: _.map(data, 'poznan'),
                    backgroundColor: '#4472C4',
                    barThickness: 75,
                },
                {
                    label: 'Juelich',
                    data: _.map(data, 'juelich'),
                    backgroundColor: '#ED7D31',
                    barThickness: 75,

                },
                {
                    label: 'Sara',
                    data: _.map(data, 'sara'),
                    backgroundColor: '#A5A5A5',
                    barThickness: 75,
                }
            ]
        };
    }

    const getBarOptions = () => {
        return {
            indexAxis: 'x',
            elements: {
                bar: {
                    borderWidth: 0,
                },
            },
            scales: {
                x: {
                    stacked: true,
                    categoryPercentage: 1.0,
                    barPercentage: 1.0
                },
                y: {
                    stacked: true,
                    // max: 5000,
                }
            },
            responsive: true,
            plugins: {
                legend: {
                    position: 'bottom',
                },
                title: {
                    display: true,
                    text: 'Ingested Data per Site (TB)',
                }
            }
        };
    }



    return (
        <React.Fragment>
            <div id={`cycles-site-data`}
                style={{ paddingTop: "10px", paddingBottom: "10px" }}>
                <Bar data={getBarData()} options={getBarOptions()} width="50%" height="20" />
            </div>

            <div className="ttd-details" id={`cycle-ttd-details`}>
                <DataTable value={data} resizableColumns columnResizeMode="expand" className="card" style={{ paddingLeft: '0em', textAlign: 'center' }}>
                    <Column field="cycle" header="Cycle Code"></Column>
                    <Column field="sara" header="To Sara (TB)"></Column>
                    <Column field="juelich" header="To Juelich (TB)"></Column>
                    <Column field="poznan" header="To Poznan (TB)"></Column>
                </DataTable>
            </div>

        </React.Fragment>
    )
}

CycleSiteWiseData.propTypes = {
    data: PropTypes.array,
};
