import { BrowserRouter as Router } from 'react-router-dom';
import renderer, { act } from 'react-test-renderer';
import axios from "axios";
import MockAdapter from 'axios-mock-adapter';
import WeekView from "./WeekView";
import Reservation from '../../__mocks__/reservation.data.json'
import SchedulingUnitBlueprintSlimWithTask from '../../__mocks__/scheduling_unit_blueprint_slim_with_task.json'
import BluePrintExtended from '../../__mocks__/blueprintsextended.json'
import moment from "moment";
import { render, waitFor } from '@testing-library/react';
const fakeauthanswer = {
    data: {
        "count": 1,
        "next": "null",
        "previous": null,
        "results": [
            {
                "name": "nothing"
            }
        ]
    }
}



const FakeSun = {
    data: {
        "CS002": {
            "sunrise": [
                {
                    "start": "2023-12-03T06:14:15.958",
                    "end": "2023-12-03T09:14:01.168"
                }
            ],
            "sunset": [
                {
                    "start": "2023-12-03T13:30:02.095",
                    "end": "2023-12-03T16:29:44.625"
                }
            ],
            "day": [
                {
                    "start": "2023-12-03T09:14:01.168",
                    "end": "2023-12-03T13:30:02.095"
                }
            ],
            "night": [
                {
                    "start": "2023-12-02T06:13:01.214",
                    "end": "2023-12-03T06:14:15.958"
                }
            ]
        }
    }
}

const FakeProjectState = {
    data: {
        "count": 5,
        "next": null,
        "previous": null,
        "results": [
            {
                "value": "opened",
                "url": "https://tmss.lofar.eu/api/project_state/opened"
            },
            {
                "value": "active",
                "url": "https://tmss.lofar.eu/api/project_state/active"
            },
            {
                "value": "finished",
                "url": "https://tmss.lofar.eu/api/project_state/finished"
            },
            {
                "value": "cancelled",
                "url": "https://tmss.lofar.eu/api/project_state/cancelled"
            },
            {
                "value": "suspended",
                "url": "https://tmss.lofar.eu/api/project_state/suspended"
            }
        ]
    }
}

const FakeSchedular = {
    data: {
        "name": "scheduler",
        "url": "https://tmss.lofar.eu/api/subsystem/scheduler",
        "created_at": "2022-10-03T08:55:11.449584",
        "description": "The scheduler subsystem takes care of scheduling all scheduling_units taking into account all their constraints and station availability",
        "status": "https://tmss.lofar.eu/api/subsystem_status/active",
        "status_value": "active",
        "tags": [],

        "updated_at": "2023-12-03T04:00:33.423663"
    }
}


const FakeProject = {
    data: {
        "count": 6,
        "next": null,
        "previous": null,
        "results": [
            {
                "name": "Calibration",
                "project_state_value": "active"
            },
            {
                "name": "COM18_001",
                "project_state_value": "opened"
            },
            {
                "name": "COM_COBALT2",
                "project_state_value": "active"
            },
            {
                "name": "DDT18_001",
                "project_state_value": "finished"
            },

            {
                "name": "high",
                "project_state_value": "suspended"
            },

            {
                "name": "LC18_019",
                "project_state_value": "opened"
            }

        ]
    }
}

const FakeFixedTimeScheduler = {
    data: {
        "url": "https://tmss.lofar.eu/api/setting/fixed_time_scheduling_enabled",
        "tags": [],
        "created_at": "2022-01-20T12:00:00",
        "updated_at": "2023-11-28T09:36:30.783393",
        "value": true
    }
}

const FakeDynamicSchedular = {
    data: {
        "url": "https://tmss.lofar.eu/api/setting/dynamic_scheduling_enabled",
        "tags": [],
        "created_at": "2021-10-11T10:54:30.647932",
        "updated_at": "2023-11-28T09:36:35.081048",
        "value": true
    }
}
function MakePrimaryMock() {
    let mock = new MockAdapter(axios);


    mock.onGet("/api/util/sun_rise_and_set?stations=CS002&timestamps=2023-12-03").reply(200, FakeSun);
    mock.onGet("/api/project_state/").reply(200, FakeProjectState);
    mock.onGet("/api/subsystem/scheduler").reply(200, FakeSchedular);
    mock.onGet("/api/project/?fields=name,project_state_value&limit=150").reply(200, FakeProject);
    mock.onGet("/api/setting/fixed_time_scheduling_enabled").reply(200, FakeFixedTimeScheduler);
    mock.onGet("/api/reservation_template").reply(200, { data: { Reservation } });
    mock.onGet("/api/setting/dynamic_scheduling_enabled").reply(200, FakeDynamicSchedular);
    mock.onGet("/api/scheduling_unit_blueprint_slim_with_tasks/?process_start_time_before=2023-12-03 23:59:59&process_stop_time_after=2023-12-03 00:00:00&id=").reply(200, SchedulingUnitBlueprintSlimWithTask);
    mock.onGet("/api/scheduling_unit_blueprint_slim_with_tasks/?id=&limit=12&offset=38&process_start_time_before=2023-12-09+23%3A59%3A59&process_stop_time_after=2023-12-03+00%3A00%3A00").reply(200, SchedulingUnitBlueprintSlimWithTask);
    mock.onGet("/api/scheduling_unit_blueprint_slim_with_tasks/?process_start_time_before=2023-12-03 23:59:59&process_stop_time_after=2023-12-03 00:00:00&id=&limit=50&offset=12").reply(200, SchedulingUnitBlueprintSlimWithTask);
    mock.onOptions("/api/scheduling_unit_blueprint_extended/").reply(200, BluePrintExtended);
    mock.onGet("/api/util/lst?timestamp=2023-12-03T00:00:00&stations=CS002").reply(200, { data: { "UTC": "2023-12-03T00:00:00Z", "LST": { "CS002": "05:13:44" } } });




}
describe('WeekView Render Contents', () => {

    it('WeekView renders correctly with data', async () => {
        MakePrimaryMock();
        let component
        await act(async () => {
            component = render(
                <Router>
                    <WeekView endTime={moment("2023-12-03").endOf('day')} startTime={moment("2023-12-03").startOf('day')}></WeekView>
                </Router>
            );
        });

        const componentSnapshot = component.asFragment();
        // Now `page` should be defined
        expect(componentSnapshot).toMatchSnapshot("DuringLoad");

        await waitFor(() => {
            expect(component.container.querySelector('.p-progressbar-value-animate')).toBeDefined();
        }, { timeout: 5000 });
        
        await act(async () => {
            component.rerender(
                <Router>
                    <WeekView endTime={moment("2023-12-03").endOf('day')} startTime={moment("2023-12-03").startOf('day')} grouping={"band_group"}></WeekView>
                </Router>
            );
        });
        expect(componentSnapshot).toMatchSnapshot("Loaded");

        component.unmount();
    });
});

