
export function getFieldsHtml(fields = [], status = undefined, style = {}) {
    const result = fields.map((field, index) => {
      try {
        const { label = '-', value = '-' } = field || {};
  
        return (
          <div key={`${label}-${index}`} className="entry">
            <label className={status ? `col-5 su-${status}-icon` : 'col-5'} style={style}>
              {label}
            </label>
            <div className="col-7">{value}</div>
          </div>
        );
      } catch (error) {
        console.error(`Error processing field at index ${index}:`, error);
        return <div key={`error-${index}`}>Error processing field</div>;
      }
    });
  
    return result;
  }

const labelObject = (label, value) => ({
    label: label,
    value: value,
})

function getScheduleItem(mouseOverItem) 
{
       const scheduleItemFields = [
        labelObject("Project:", mouseOverItem.project),
        labelObject("Scheduling Unit:", mouseOverItem.name),
        labelObject("Scheduler:", mouseOverItem.scheduler),
        labelObject("Start Time:", mouseOverItem.real_start_time),
        labelObject("End Time:", mouseOverItem.real_end_time),
        labelObject("Antenna Set:", mouseOverItem.antenna_set),
        labelObject("Stations:", mouseOverItem.stations),
        labelObject("Status:", mouseOverItem.status),
        labelObject("Exposure Time:", mouseOverItem.on_sky_duration),
        labelObject("Duration:", mouseOverItem.duration),

    ];
    if (mouseOverItem.status === 'unschedulable') {
        scheduleItemFields.push({ label: "Reason:", value: mouseOverItem.unschedulable_reason })
    }

    if (mouseOverItem.task) {
        scheduleItemFields.push({ label: "Task:", value: mouseOverItem.task.name })
    }
    const suId = mouseOverItem.suId ? mouseOverItem.suId : mouseOverItem.id;
    const fieldsHTML = getFieldsHtml(scheduleItemFields, mouseOverItem.status)
    return (
        <div className={`p-grid su-${mouseOverItem.status} timeline-item-popover`}>
            <h3 className={`col-12 su-${mouseOverItem.status}-icon su-${mouseOverItem.status}-header`} >
                Scheduling Unit ({suId}) Overview
            </h3>
            {fieldsHTML}
        </div>
    );
}

function getReservationItem(mouseOverItem) {
    
    let reservationItemFields = [
        labelObject("Name:", mouseOverItem.name),
        labelObject("Description:", mouseOverItem.desc),
        labelObject("Type:", mouseOverItem.activity_type),
        labelObject("Stations:", mouseOverItem.stations),
        labelObject("Project:", mouseOverItem.project ? mouseOverItem.project : "-"),
        labelObject("Start Time:", mouseOverItem.real_start_time),
        labelObject("End Time:", mouseOverItem.real_end_time),
        labelObject("Duration:", mouseOverItem.duration),
        labelObject("Planned:", mouseOverItem.planned ? "Yes" : "No"),
    ];

    const reservationStyle = {
        width: '350px',
        backgroundColor: mouseOverItem.bgColor,
        color: mouseOverItem.color
    };
    return <div className={`p-grid timeline-item-popover`} style={reservationStyle}>
        <h3 className={`col-12`}>{"Reservation (" + mouseOverItem.reservationId + ") Overview"}</h3>
        {getFieldsHtml(reservationItemFields, undefined, { color: mouseOverItem.color })}
    </div>;
}



function getSunTimeItem(mouseOverItem) {
    
    let momentum
    if (mouseOverItem.id?.startsWith("sunrise")) momentum="sunrise"
    if (mouseOverItem.id?.startsWith("sunset")) momentum="sunset"
    if (!momentum) return null;
    const Suntyle = {
        width: '175px',
        backgroundColor: mouseOverItem.bgColor,
        color: mouseOverItem.color,
        paddingleft:'5px'
    };
    return <div className={`p-grid timeline-item-popover`} style={Suntyle}>
        <span> <b>&nbsp;{momentum} </b> {mouseOverItem.start_time?.format("HH:mm:ss")} - {mouseOverItem.end_time?.format("HH:mm:ss")} </span>
        
        
    </div>;
}


/**
 * @param mouseOverItem the item with all it's information to be shown in the pop-up
 * @return {*|null} the specific html for the type that is hovered over
 */
function getItemForType(mouseOverItem) {
            switch (mouseOverItem.type) {
            case "SCHEDULE":
                return getScheduleItem(mouseOverItem)
            case "RESERVATION":
                return getReservationItem(mouseOverItem)
            case "SUNTIME":
                return getSunTimeItem(mouseOverItem);
            default: //when there should not be a pop-over; like a sun timing
                return null;
        }
    }

/**
 * In the timeline, when hovering over an item, this popover will be shown
 * @param props mouseOverItem: the item with all it's information to be shown in the pop-up
 */
export default function TimelineItemPopover(props) {

    try {
        const { mouseOverItem } = props;
        if (!mouseOverItem) {
            return;
        }
        return <div className="p-overlaypanel-content">
            {getItemForType(mouseOverItem)}
        </div>
    }
    catch (e) {
        return <div className="p-overlaypanel-content">
            Error parsing
            </div>
    }
}
