import * as HelperFunctions from "../../helpers/toolbar/zoomandmove.helper";
import ZoomAndMove from "./ZoomAndMove";
import {render,waitFor,act} from "@testing-library/react";
import {clickItem, removeReact18ConsoleErrors} from "../../../../utils/test.helper";
import UIConstants from "../../../../utils/ui.constants";

removeReact18ConsoleErrors()

jest.mock('../../../../services/store.helper', () => ({
    updateStore: jest.fn(),
}));
jest.mock('../../helpers/toolbar/zoomandmove.helper', () => ({
    moveTimeline: jest.fn(),
    getZoomPossibilities: jest.fn(),
    getMovePossibilities: jest.fn(),
    getZoomTimes: jest.fn(),
    getTimeStepsForZoom: jest.fn(),
}));


const headerSettings = {
    timeSteps: UIConstants.ALL_TIMESTEPS[0],
    unit:  "hour",
    lstShiftInSeconds: 0
};


describe('ZoomAndMove', () => {
    const mockTimelineStore = {
        zoomLevel: undefined,
    };
    const mockSetVisibleTime = jest.fn();
    const mockVisibleStartTime = '01:00';
    const mockVisibleEndTime = '23:00';
    const mockSetTimeSteps = jest.fn();
    const mockSetHeaderSettings = jest.fn();

    beforeEach(() => {
        HelperFunctions.getZoomTimes.mockImplementation(() => {
            return {start: mockVisibleStartTime, end: mockVisibleEndTime}
        });
        HelperFunctions.getZoomPossibilities.mockImplementation(() => {
            return {canZoomIn: true, canZoomOut: true}
        });
        HelperFunctions.getMovePossibilities.mockImplementation(() => {
            return {moveLeft: true, moveRight: true}
        })
        HelperFunctions.getTimeStepsForZoom.mockReturnValue(() => UIConstants.ALL_TIMESTEPS[0]);
    });

    afterEach(() => {
        jest.clearAllMocks();

    })
    

    it('renders loading spinner when props are not yet available', () => {
        let moctm = mockTimelineStore;
       const {getByRole}= render(
            <ZoomAndMove
                timelineStore={moctm}
            />
        );

        expect(getByRole('alert',{ busy: true })).toBeInTheDocument();
    });
    

  


     // This test could be improved, by actually having some real setters and getters, in orde to see the difference in movement
    it('renders components and clicks them when data is available', async () => {
        const defaultTimeSteps = UIConstants.ALL_TIMESTEPS[0]
        jest.spyOn(HelperFunctions, 'getTimeStepsForZoom').mockImplementation(() => {
            // Mock implementation of getTimeStepsForZoom here
            return UIConstants.ALL_TIMESTEPS[0]
        });

        let pageContent
        act(()=>
         pageContent = render(
            <ZoomAndMove
                timelineStore={mockTimelineStore}
                visibleTime={mockSetVisibleTime}
                setVisibleTime={mockSetVisibleTime}
                setTimeSteps={mockSetTimeSteps}
                headerSettings={headerSettings}
                setHeaderSettings={mockSetHeaderSettings}
            />
        ));

        await waitFor(() =>expect(pageContent.getByTestId('zoom-select')).toBeInTheDocument());
        clickItem(pageContent.getByTestId('Zoom out'))
        expect(mockSetVisibleTime).toHaveBeenNthCalledWith(2, { start:mockVisibleStartTime,end:mockVisibleEndTime});

       
        clickItem(pageContent.getByTestId('Move Left 1 hour'))
        expect(mockSetVisibleTime).toHaveBeenNthCalledWith(2, { start:mockVisibleStartTime,end:mockVisibleEndTime});// no extra calls here

        clickItem(pageContent.getByTestId('zoom-reset-button'))
        expect(mockSetVisibleTime).toHaveBeenNthCalledWith(2, { start:mockVisibleStartTime,end:mockVisibleEndTime}); // no extra calls here
       
    });
    
});