import UIConstants from '../../../utils/ui.constants';

function getItemDivStyle(itemContext, item, hasItemColors = false) {
    const style = {
        borderRadius: 3,
        border: 'none',
        overflow: "hidden",
        textOverflow: "ellipsis",
    };
    if (hasItemColors) {
        style.color = item.color
        style.background =  item.bgColor
        style.opacity = item.opacity ? item.opacity : 100
    }
    if (item.type=="SUNTIME") {
        style.cursor='default';
    }
     return style;
}

function getItemContentStyle(itemContext,
    lineHeightScale = 2,
    fontSize = 14) {
    return {
        lineHeight: `${Math.floor(itemContext.dimensions.height / lineHeightScale)}px`,
        fontSize: `${fontSize}px`,
        textAlign: "center",
    };
}

function calculatePopPosition(evt, ignoreHeighAdjust) {
    let popPosition = {
        display: "block",
        left: `${evt.pageX + 400 > window.innerWidth ? evt.pageX - 400 : evt.pageX + 20}px`
    };

    if (evt.clientY > window.screen.height / 2) {
        if (!ignoreHeighAdjust) {
            popPosition.top = `${evt.pageY - 400}px`; // Bottem line position will not work here
        }
        else
        {
            popPosition.top = `${evt.pageY}px`;    
        }
    } else {
        popPosition.top = `${evt.pageY}px`;
    }
    return popPosition;
}

function hoverOverItem(evt, item, setPopPositionCallback, setMouseOverItemCallback) {

    let popPosition = calculatePopPosition(evt,item?.type==="SUNTIME");
    setMouseOverItemCallback(item)
    setPopPositionCallback(popPosition)
}

function hoverOutItem(setPopPositionCallback) {
    setPopPositionCallback({ display: 'none' })
}

function renderSunTimingItem({
    item,
    itemContext,
    getItemProps
},setPopPositionCallback, setMouseOverItemCallback) {
    itemContext.dimensions.height = 20

    return <div {...getItemProps({ style: { ...getItemDivStyle(itemContext, item, true), height: "90%" } })}
    onMouseOver={(evt) => {
        hoverOverItem(evt, item, setPopPositionCallback, setMouseOverItemCallback)
    }}
    onFocus={(evt) => {
        hoverOverItem(evt, item, setPopPositionCallback, setMouseOverItemCallback)
    }}
    onMouseOut={() => {
        hoverOutItem(setPopPositionCallback)
    }}
    onBlur={() => {
        hoverOutItem(setPopPositionCallback)
    }}
    >
    </div>
}

function renderReservationItem({
    item,
    itemContext,
    getItemProps
}, setPopPositionCallback, setMouseOverItemCallback, setSummaryItemCallback) {
    let itemContentStyle = getItemContentStyle(itemContext);

    return <div {...getItemProps({ style: getItemDivStyle(itemContext, item, true) })}
        onMouseDown={() => setSummaryItemCallback({ id: item.reservationId, type: item.type })}
        onMouseOver={(evt) => {
            hoverOverItem(evt, item, setPopPositionCallback, setMouseOverItemCallback)
        }}
        onFocus={(evt) => {
            hoverOverItem(evt, item, setPopPositionCallback, setMouseOverItemCallback)
        }}
        onMouseOut={() => {
            hoverOutItem(setPopPositionCallback)
        }}
        onBlur={() => {
            hoverOutItem(setPopPositionCallback)
        }}
    >
        <div style={itemContentStyle}>
            {item.activity_type}
            <div>{item.desc}</div>
        </div>
    </div>
}

function renderSUItem({
    item,
    itemContext,
    getItemProps
}, setPopPositionCallback, setMouseOverItemCallback, setSummaryItemCallback) {
    const scheduleMethodBorder = item.scheduler === "dynamic" ? "1.5px dashed black " : "1.5px solid black"
    let itemDivStyle = getItemDivStyle(itemContext, item);
    itemDivStyle.fontWeight = 600
    itemDivStyle.border = scheduleMethodBorder
    
    let itemContentStyle = getItemContentStyle(itemContext, 3, 12)
    let itemContent = `${item.project} - ${item.suId ? item.suId : item.id} - ${item.name} - ${item.band} - ${item.on_sky_duration}`

    return <div {...getItemProps({
        style: itemDivStyle,
        className: `${item.status ? 'su-' + item.status : ''}`,
    })}
        onMouseDown={() => setSummaryItemCallback({ id: item.suId, type: item.type,item:item })}
        onMouseOver={(evt) => {
            hoverOverItem(evt, item, setPopPositionCallback, setMouseOverItemCallback)
        }}
        onFocus={(evt) => {
            hoverOverItem(evt, item, setPopPositionCallback, setMouseOverItemCallback)
        }}
        onMouseOut={() => {
            hoverOutItem(setPopPositionCallback)
        }}
        onBlur={() => {
            hoverOutItem(setPopPositionCallback)
        }}
    >
        <div style={itemContentStyle}>
            {itemContent}
        </div>
    </div>
}

/** Custom function to pass to timeline component to render item */
export function itemRenderer({ item, timelineContext, itemContext, getItemProps, getResizeProps },
    setPopPositionCallback, setMouseOverItemCallback, setSummaryItemCallback) {
    switch (item.type) {
        case "RESERVATION":
            return renderReservationItem({
                item,
                itemContext,
                getItemProps
            }, setPopPositionCallback, setMouseOverItemCallback, setSummaryItemCallback)
        case "SCHEDULE":
            return renderSUItem({
                item,
                itemContext,
                getItemProps
            }, setPopPositionCallback, setMouseOverItemCallback, setSummaryItemCallback)
        default: //a sun timings
            return renderSunTimingItem({
                item,
                itemContext,
                getItemProps
            }, setPopPositionCallback,setMouseOverItemCallback)
    }
}

export function groupRenderer({ group }) {

    let primaryGroupTitle = null;
    let groupClassName = "group-renderer";
    const doesContainHash = group.id.indexOf('#') !== -1;
    let weekdate = group.weekdate

    if (doesContainHash) {
        primaryGroupTitle = group.title
        groupClassName = groupClassName + ' ' + group.titleClass
    } 
        weekdate =  ( <a href={"/constraint/view/" + group.date.format(UIConstants.CALENDAR_DEFAULTDATE_FORMAT)} target="_new"> {weekdate} </a> )
    



    return <div className={groupClassName} >
        {primaryGroupTitle ? <div className="group-primary-title">{primaryGroupTitle}</div> : null}
        <span className="week">{group.weeknr}</span>
        {weekdate}

        {group.cursorInfo ?
            <table className="cursor-information"><tbody>
                <tr><td>UTC</td><td> {group.cursorInfo.utc}</td></tr>
                {group.isSingleStation ? (
                    <tr>
                        <td>LST {group.cursorInfo.stationName || 'Station' } </td>
                        <td>{group.cursorInfo.stationLST}</td>
                    </tr>
                ) : null}
                <tr><td>LST Core </td><td>{group.cursorInfo.coreLST}</td></tr>
</tbody>             
            </table> : null}
    </div>;
}