import { useState, useEffect } from 'react';
import { DataTable } from 'primereact/datatable';
import { Column } from 'primereact/column';
import PermissionStackUtil from '../../authenticate/permission.stack.handler';
const UserOverView = () => {
const [permissions, setPermissions] = useState();

  useEffect(() => {
    const fetchData =  async () => {
      try {
          const userPermissions = await PermissionStackUtil.getPermissions(true);
          delete userPermissions["token"];
          
          const objectpermissions = Object.entries(userPermissions);
          
          setPermissions(objectpermissions);
      } catch (error) {
        console.info('Error fetching user permissions:', error);
      }
    };

    fetchData();
  }, []); // The empty dependency array ensures that this effect runs once when the component mounts
  
  function  checkMarkTemplate (rowData, field)  {
  let fieldvalue;
    if (field!==undefined) fieldvalue=rowData?.[1]?.[field]
    const classes = fieldvalue===true ? 'pi true-icon pi-check-circle' : '';
    return <i className={classes}></i>;
}





  return (
    <div>
    <div>
      
      {( permissions && permissions.length>0)  && (
      <DataTable value={permissions}   scrollable  showGridlines stripedRows >
        <Column field="0" header="Module"   />
        <Column field="1.create" header="Create" dataType="boolean" body={(rowData ) => checkMarkTemplate(rowData,"create")} />
        <Column field="1.edit" header="Edit" dataType="boolean"  body={(rowData ) => checkMarkTemplate(rowData, "edit")} />
        <Column field="1.delete" header="Delete" dataType="boolean"  body={(rowData ) => checkMarkTemplate(rowData,"delete")} />
        <Column field="1.list" header="List" dataType="boolean"  body={(rowData ) => checkMarkTemplate(rowData,"list")}  />
        <Column field="1.add" header="Add" dataType="boolean" body={(rowData ) => checkMarkTemplate(rowData,"add")}  />
        <Column field="1.setting" header="Setting" dataType="boolean"  body={(rowData ) => checkMarkTemplate(rowData,"setting")}  />
        <Column field="1.canceltask" header="Cancel Task" dataType="boolean"  body={(rowData ) => checkMarkTemplate(rowData,"canceltask")}  />
        <Column field="1.addreservation" header="addreservation" dataType="boolean"  body={(rowData ) => checkMarkTemplate(rowData,"addreservation")}  />
        <Column field="1.addsystemevent" header="addsystemevent" dataType="boolean"  body={(rowData ) => checkMarkTemplate(rowData,"addsystemevent")}  />
        <Column field="1.listreservation" header="listreservation" dataType="boolean"  body={(rowData ) => checkMarkTemplate(rowData,"listreservation")}  />
        <Column field="1.listsystemevent" header="listsystemevent" dataType="boolean"  body={(rowData ) => checkMarkTemplate(rowData,"listsystemevent")}  />
        <Column field="1.decide_acceptance" header="decide_acceptance" dataType="boolean"  body={(rowData ) => checkMarkTemplate(rowData,"decide_acceptance")}  />
        <Column field="1.pi_verification" header="pi_verification" dataType="boolean"  body={(rowData ) => checkMarkTemplate(rowData,"pi_verification")}  />
        <Column field="1.qa_reporting_sos" header="qa_reporting_sos" dataType="boolean"  body={(rowData ) => checkMarkTemplate(rowData,"qa_reporting_sos")}  />
        <Column field="1.qa_reporting_to" header="qa_reporting_to" dataType="boolean"  body={(rowData ) => checkMarkTemplate(rowData,"qa_reporting_to")}  />
        <Column field="1.unpin_data" header="unpin_data" dataType="boolean"  body={(rowData ) => checkMarkTemplate(rowData,"unpin_data")}   />
      </DataTable>
)}
    </div>
    </div>
  );
};

export default UserOverView;
